@@ -34,6 +34,7 @@ use YAML::XS ();
 use constant {
     DCTRL_DEBCONF_TEMPLATE => 1,
     DCTRL_NO_COMMENTS => 2,
+    DCTRL_COMMENTS_AT_EOL => 4,
 };
 
 # Force export as soon as possible, since some of the modules we load also
@@ -43,7 +44,9 @@ our (@EXPORT_OK, %EXPORT_TAGS);
 
 BEGIN {
     %EXPORT_TAGS
-      = (constants => [qw(DCTRL_DEBCONF_TEMPLATE DCTRL_NO_COMMENTS)]);
+      = (constants =>
+          [qw(DCTRL_DEBCONF_TEMPLATE DCTRL_NO_COMMENTS DCTRL_COMMENTS_AT_EOL)]
+      );
 
     eval { require PerlIO::gzip };
     if ($@) {
@@ -437,7 +440,7 @@ sub visit_dpkg_paragraph {
         # empty line?
         if ($_ eq '' || (!$debconf && m/^\s*$/)) {
             if ($open_section) { # end of current section
-                # pass the current section to the handler
+                 # pass the current section to the handler
                 $code->($section, $lines);
                 $section = {};
                 $lines = {};
@@ -576,6 +579,7 @@ sub visit_dpkg_paragraph {
                 # of a particular field name.
                 die "syntax error at line $.: Duplicate field $tag.\n";
             }
+            $value =~ s/#.*$// if $flags & DCTRL_COMMENTS_AT_EOL;
             $section->{$tag} = $value;
             $lines->{$tag} = $.;
 
@@ -594,6 +598,7 @@ sub visit_dpkg_paragraph {
             # trailing spaces or tabs at the end of individual lines of a
             # field value are ignored.
             my $value = rstrip($1);
+            $value =~ s/#.*$// if $flags & DCTRL_COMMENTS_AT_EOL;
             $section->{$last_tag} .= "\n" . $value;
         }
         # None of the above => syntax error
@@ -904,8 +909,16 @@ sub do_fork() {
             }
         }
     }
-    sigprocmask(SIG_SETMASK, $orig_mask, undef)
-      or die("sigprocmask failed: $!\n");
+    if (!sigprocmask(SIG_SETMASK, $orig_mask, undef)) {
+        # The child MUST NOT use die as the caller cannot distinguish
+        # the caller from the child via an exception.
+        my $sigproc_error = $!;
+        if (not defined($pid) or $pid != 0) {
+            die("sigprocmask failed (do_fork, parent): $sigproc_error\n");
+        }
+        print STDERR "sigprocmask failed (do_fork, child): $sigproc_error\n";
+        POSIX::_exit(255);
+    }
     if (not defined($pid)) {
         $! = $fork_error;
     }
@@ -997,7 +1010,7 @@ sub perm2oct {
                     ([-r])([-w])([-xsS])     # group
                     ([-r])([-w])([-xtT])     # other
                /xsmo
-      ) {
+    ) {
         croak "$t does not appear to be a permission string";
     }
 
